Rename "User" role "ReadOnly"

https://gerrit.openbmc-project.xyz/c/openbmc/bmcweb/+/26156
is renaming the User role ReadOnly. Update the Roles table.

26156 needs to merge first.

Tested: Loaded on a Witherspoon.
Change-Id: I948a6287d2c447072d5c34595589387e127d59ac
Signed-off-by: Gunnar Mills <gmills@us.ibm.com>
diff --git a/app/access-control/directives/role-table.js b/app/access-control/directives/role-table.js
index fb19dab..a6dcbfd 100644
--- a/app/access-control/directives/role-table.js
+++ b/app/access-control/directives/role-table.js
@@ -21,14 +21,14 @@
               $sce.trustAsHtml(`<span class="icon__check-mark">${svg}<span>`);
 
           this.tableHeader = [
-            {label: ''}, {label: 'Admin'}, {label: 'Operator'}, {label: 'User'},
-            {label: 'Callback'}
+            {label: ''}, {label: 'Admin'}, {label: 'Operator'},
+            {label: 'ReadOnly'}, {label: 'Callback'}
           ];
 
           // TODO: When API changed from D-Bus to Redfish, 'Operator' role
           // should have 'Configure components managed by this service'
           // privilege checked
           // TODO: When 'Operator' and 'User' roles have ability to change
           // own account's passwords, should have 'Update password for
           // current user account' privilege checked
           // TODO: Update Callback privileges when backend removes privileges
@@ -21,14 +21,14 @@
           // should have 'Configure components managed by this service'
           // privilege checked
-          // TODO: When 'Operator' and 'User' roles have ability to change
+          // TODO: When 'Operator' and 'ReadOnly' roles have ability to change
           // own account's passwords, should have 'Update password for
           // current user account' privilege checked